local AddonName, a = ...
if a.BuildFail(50000) then return end
local L = a.Localize
local s = SpellFlashAddon
local x = s.UpdatedVariables
local talent = x.Talent
local equipped = x.Equipped
local dot = x.Dot
local buff = x.Buff
local debuff = x.Debuff
local cooldown = x.Cooldown
local set_bonus = x.SetBonus
local target = x.Target
local variable = x.Variables

-- SpellFlash API:
-- http://wow.curseforge.com/addons/spellflash/pages/api/

-- Updated variable references:
-- http://wow.curseforge.com/addons/spellflash/pages/api/#w-local-x-spell-flash-addon-updated-variables
-- x.EnemyDetected, x.NoCC, x.InInstance, x.InstanceType, x.PetAlive, x.PetActiveEnemy, x.PetNoCC, x.Lag, x.DoubleLag, x.ThreatPercent, x.ShouldPermanentBuff, x.ShouldTemporaryBuff

-- Spell table references:
-- http://wow.curseforge.com/addons/spellflash/pages/api/#w-s-castable

-- Example flash color coding:
-- White - Default
-- Yellow - Limited Time or No Global Cooldown
-- Purple - AOE or Positional Damage
-- Blue - AOE Debuff
-- Orange - Finishing Move
-- Aqua - Spell Interrupt, Reflect or Dispel
-- Green - Self Buff or Turn Autocast On
-- Red - Emergency Mitigation Cooldowns or Turn Autocast Off
-- Pink - Optional

a.spells["hand_of_reckoning"] = {
	ID = 62124--[[Hand of Reckoning]],
	EnemyTargetNeeded = true,
	Check = function(z)
		return x.ThreatPercent <= 99 and ( GetNumGroupMembers() > 1 or GetNumSubgroupMembers() > 0 ) and x.InCombat and s.UnitInfo("target") ~= "player" and x.InstanceType ~= "pvp"
	end,
	NoGCD = true,
	FlashColor = "Purple",
}

a.spells["avenging_wrath"] = {
	ID = 31884--[[Avenging Wrath]],
	Check = function(z)
		return true
	end,
	FlashColor = "Pink",
}

a.spells["seraphim"] = {
	ID = 152262--[[Seraphim]],
	Check = function(z)
		return true
	end,
	FlashColor = "Pink",
}
,"fireblood,if=buff.avenging_wrath.up"

a.spells["seraphim,if=cooldown.shield_of_the_righteous.charges_fractional>=2"] = {
	ID = 152262--[[Seraphim]],
	Check = function(z)
		return x.InCombat and cooldown.shield_of_the_righteous.charges_fractional >= 2
	end,
	FlashColor = "Pink",
	Continue = true,
}

a.spells["avenging_wrath,if=buff.seraphim.up|cooldown.seraphim.remains<2|!talent.seraphim.enabled"] = {
	ID = 31884--[[Avenging Wrath]],
	Check = function(z)
		return x.UseLongCD and (buff.seraphim.up or cooldown.seraphim.remains < 2 or not talent.seraphim.enabled)
	end,
	FlashColor = "Pink",
	Continue = true,
}

a.spells["bastion_of_light,if=cooldown.shield_of_the_righteous.charges_fractional<=0.5"] = {
	ID = 204035--[[Bastion of Light]],
	Check = function(z)
		return x.UseLongCD and cooldown.shield_of_the_righteous.charges_fractional_nogcd <= 0.5
	end,
	FlashColor = "Yellow",
	NoGcd = true,
}

,"potion,if=buff.avenging_wrath.up"

a.spells["shield_of_the_righteous,if=(buff.avengers_valor.up&cooldown.shield_of_the_righteous.charges_fractional>=2.5)&(cooldown.seraphim.remains>gcd|!talent.seraphim.enabled)"] = {
	ID = 53600--[[Shield of the Righteous]],
	Buff = 53600--[[Shield of the Righteous]],
	BuffUnit = "player",
	Check = function(z)
		return x.InCombat and (buff.avengers_valor.up_nogcd and cooldown.shield_of_the_righteous.charges_fractional_nogcd >= 2.5) and (cooldown.seraphim.remains_nogcd > x.GCD or not talent.seraphim.enabled)
	end,
	NoRangeCheck = true,
	FlashColor = "Yellow",
	NoGcd = true,
	Melee = true,
	Continue = true,
}

a.spells["shield_of_the_righteous,if=(buff.avenging_wrath.up&!talent.seraphim.enabled)|buff.seraphim.up&buff.avengers_valor.up"] = {
	ID = 53600--[[Shield of the Righteous]],
	Buff = 53600--[[Shield of the Righteous]],
	BuffUnit = "player",
	Check = function(z)
		return x.InCombat and ((buff.avenging_wrath.up_nogcd and not talent.seraphim.enabled) or buff.seraphim.up_nogcd and buff.avengers_valor.up_nogcd)
	end,
	NoRangeCheck = true,
	FlashColor = "Yellow",
	NoGcd = true,
	Melee = true,
	Continue = true,
}

a.spells["shield_of_the_righteous,if=(buff.avenging_wrath.up&buff.avenging_wrath.remains<4&!talent.seraphim.enabled)|(buff.seraphim.remains<4&buff.seraphim.up)"] = {
	ID = 53600--[[Shield of the Righteous]],
	Buff = 53600--[[Shield of the Righteous]],
	BuffUnit = "player",
	Check = function(z)
		return x.InCombat and ((buff.avenging_wrath.up_nogcd and buff.avenging_wrath.remains_nogcd < 4 and not talent.seraphim.enabled) or (buff.seraphim.remains_nogcd < 4 and buff.seraphim.up_nogcd))
	end,
	NoRangeCheck = true,
	FlashColor = "Yellow",
	NoGcd = true,
	Melee = true,
	Continue = true,
}

a.spells["light_of_the_protector,if=health.pct<40"] = {
	ID = 184092--[[Light of the Protector]],
	Check = function(z)
		return not talent.hand_of_the_protector.enabled and x.HealthPercent < 40
	end,
--	FlashColor = "Red",
--	Continue = true,
}

a.spells["hand_of_the_protector,if=health.pct<40"] = {
	ID = 213652--[[Hand of the Protector]],
	Check = function(z)
		return talent.hand_of_the_protector.enabled and x.HealthPercent < 40
	end,
	NoRangeCheck = true,
--	FlashColor = "Red",
--	Continue = true,
}

a.spells["light_of_the_protector,if=(incoming_damage_6000ms<health.max*0.7)&health.pct<65&talent.righteous_protector.enabled"] = {
	ID = 184092--[[Light of the Protector]],
	Check = function(z)
		return not talent.hand_of_the_protector.enabled and (s.IncomingDamage(6000) < x.MaxHealth * 0.7) and x.HealthPercent < 65 and talent.righteous_protector.enabled
	end,
--	FlashColor = "Red",
--	Continue = true,
}

a.spells["hand_of_the_protector,if=(incoming_damage_6000ms<health.max*0.7)&health.pct<65&talent.righteous_protector.enabled"] = {
	ID = 213652--[[Hand of the Protector]],
	Check = function(z)
		return talent.hand_of_the_protector.enabled and (s.IncomingDamage(6000) < x.MaxHealth * 0.7) and x.HealthPercent < 65 and talent.righteous_protector.enabled
	end,
	NoRangeCheck = true,
--	FlashColor = "Red",
--	Continue = true,
}

a.spells["light_of_the_protector,if=(incoming_damage_9000ms<health.max*1.2)&health.pct<55"] = {
	ID = 184092--[[Light of the Protector]],
	Check = function(z)
		return not talent.hand_of_the_protector.enabled and (s.IncomingDamage(9000) < x.MaxHealth * 1.2) and x.HealthPercent < 55
	end,
--	FlashColor = "Red",
--	Continue = true,
}

a.spells["hand_of_the_protector,if=(incoming_damage_9000ms<health.max*1.2)&health.pct<55"] = {
	ID = 213652--[[Hand of the Protector]],
	Check = function(z)
		return talent.hand_of_the_protector.enabled and (s.IncomingDamage(9000) < x.MaxHealth * 1.2) and x.HealthPercent < 55
	end,
	NoRangeCheck = true,
--	FlashColor = "Red",
--	Continue = true,
}

a.spells["lay_on_hands,if=health.pct<15"] = {
	ID = 633--[[Lay on Hands]],
	Check = function(z)
		return x.InCombat and x.HealthPercent < 15
	end,
	EnemyTargetNeeded = false,
	NoRangeCheck = true,
	FlashColor = "Red",
	FlashBlink = true,
	NoGcd = true,
}

a.spells["consecration,if=!consecration.up"] = {
	ID = 26573--[[Consecration]],
	Buff = 188370--[[Consecration]],
	BuffUnit = "player",
	NoRangeCheck = true,
	Melee = true,
	Check = function(z)
		return x.InCombat
	end,
}

a.spells["judgment,if=(cooldown.judgment.remains<gcd&cooldown.judgment.charges_fractional>1&cooldown_react)|!talent.crusaders_judgment.enabled"] = {
	ID = 20271--[[Judgement]],
	Check = function(z)
		return x.EnemyDetected and ((cooldown.judgment.remains < x.MaxGCD and cooldown.judgment.charges_fractional > 1) or not talent.crusaders_judgment.enabled)
	end,
}

a.spells["avengers_shield,,if=cooldown_react"] = {
	ID = 31935--[[Avenger's Shield]],
	Check = function(z)
		return x.EnemyDetected
	end,
}

a.spells["judgment,if=cooldown_react|!talent.crusaders_judgment.enabled"] = {
	ID = 20271--[[Judgement]],
	Check = function(z)
		return x.EnemyDetected
	end,
}

a.spells["blessed_hammer,strikes=2"] = {
	ID = 204019--[[Blessed Hammer]],
	NoRangeCheck = true,
	Melee = true,
	Check = function(z)
		return x.ActiveEnemy and talent.blessed_hammer.enabled
	end,
}

a.spells["hammer_of_the_righteous"] = {
	ID = 53595--[[Hammer of the Righteous]],
	Check = function(z)
		return x.ActiveEnemy and not talent.blessed_hammer.enabled
	end,
}

a.spells["consecration"] = {
	ID = 26573--[[Consecration]],
	NoRangeCheck = true,
	Melee = true,
	Check = function(z)
		return x.InCombat
	end,
}
