local AddonName, a = ...
if a.BuildFail(50000) then return end
local L = a.Localize
local s = SpellFlashAddon
local x = s.UpdatedVariables
local talent = x.Talent
local equipped = x.Equipped
local dot = x.Dot
local buff = x.Buff
local debuff = x.Debuff
local cooldown = x.Cooldown
local set_bonus = x.SetBonus
local target = x.Target
local variable = x.Variable
local azerite = x.Azerite

-- SpellFlash API:
-- http://wow.curseforge.com/addons/spellflash/pages/api/

-- Updated variable references:
-- http://wow.curseforge.com/addons/spellflash/pages/api/#w-local-x-spell-flash-addon-updated-variables
-- x.EnemyDetected, x.EnemyDetected, x.NoCC, x.InInstance, x.InstanceType, x.PetAlive, x.PetActiveEnemy, x.PetNoCC, x.Lag, x.DoubleLag, x.ThreatPercent, x.EnemyDetected, x.ShouldPermanentBuff, x.ShouldTemporaryBuff

-- Spell table references:
-- http://wow.curseforge.com/addons/spellflash/pages/api/#w-s-castable

-- Example flash color coding:
-- White - Default
-- Yellow - Limited Time or No Global Cooldown
-- Purple - AOE or Positional Damage
-- Blue - AOE Debuff
-- Orange - Finishing Move
-- Aqua - Spell Interrupt, Reflect or Dispel
-- Green - Self Buff or Turn Autocast On
-- Red - Emergency Mitigation Cooldowns or Turn Autocast Off
-- Pink - Optional

a.spells["arcane_torrent,if=!talent.wake_of_ashes.enabled"] = {
	ID = 155145--[[Arcane Torrent]],
	NoRangeCheck = true,
	Melee = true,
	CheckFirst = function(z)
		return not talent.wake_of_ashes.enabled
	end,
}

--[[
   ____            _     _                         
  / ___|___   ___ | | __| | _____      ___ __  ___ 
 | |   / _ \ / _ \| |/ _` |/ _ \ \ /\ / / '_ \/ __|
 | |__| (_) | (_) | | (_| | (_) \ V  V /| | | \__ \
  \____\___/ \___/|_|\__,_|\___/ \_/\_/ |_| |_|___/
                                                   ]]
,"use_item,name=jes_howler,if=buff.avenging_wrath.up|buff.crusade.up&buff.crusade.stack=10"
,"potion,if=(buff.bloodlust.react|buff.avenging_wrath.up|buff.crusade.up&buff.crusade.remains<25|target.time_to_die<=40)"
,"lights_judgment,if=spell_targets.lights_judgment>=2|(!raid_event.adds.exists|raid_event.adds.in>75)"
,"fireblood,if=buff.avenging_wrath.up|buff.crusade.up&buff.crusade.stack=10"

a.spells["shield_of_vengeance"] = {
	ID = 184662--[[Shield of Vengeance]],
	NoRangeCheck = true,
	Melee = true,
	CheckFirst = function(z)
		return x.UseLongCD
	end,
	FlashColor = "Pink",
}

a.spells["avenging_wrath,if=buff.inquisition.up|!talent.inquisition.enabled"] = {
	ID = 31884--[[Avenging Wrath]],
	NoRangeCheck = true,
	Melee = true,
	CheckFirst = function(z)
		return x.UseLongCD
	end,
	FlashColor = "Pink",
}

a.spells["crusade,if=holy_power>=4"] = {
	ID = 231895--[[Crusade]],
	NoRangeCheck = true,
	Melee = true,
	CheckFirst = function(z)
		return x.UseLongCD and x.HolyPower >= 4
	end,
	FlashColor = "Pink",
}

--[[
  _____ _       _     _                   
 |  ___(_)_ __ (_)___| |__   ___ _ __ ___ 
 | |_  | | '_ \| / __| '_ \ / _ \ '__/ __|
 |  _| | | | | | \__ \ | | |  __/ |  \__ \
 |_|   |_|_| |_|_|___/_| |_|\___|_|  |___/
                                          ]]

a.spells["inquisition,if=buff.inquisition.down|buff.inquisition.remains<5&holy_power>=3|talent.execution_sentence.enabled&cooldown.execution_sentence.remains<10&buff.inquisition.remains<15|cooldown.avenging_wrath.remains<15&buff.inquisition.remains<20&holy_power>=3"] = {
	ID = 84963--[[Inquisition]],
	NoRangeCheck = true,
	CheckFirst = function(z)
		return buff.inquisition.down or buff.inquisition.remains < 5 and x.HolyPower >= 3 or talent.execution_sentence.enabled and cooldown.execution_sentence.remains < 10 and buff.inquisition.remains < 15 or cooldown.avenging_wrath.remains < 15 and buff.inquisition.remains < 20 and x.HolyPower >= 3
	end,
}

a.spells["execution_sentence,if=spell_targets.divine_storm<=2&(!talent.crusade.enabled|cooldown.crusade.remains>gcd*2)"] = {
	ID = 267798--[[Execution Sentence]],
	CheckFirst = function(z)
		return x.ActiveEnemies <= 2 and (not talent.crusade.enabled or cooldown.crusade.remains > x.MaxGCD * 2 or not x.UseLongCD)
	end,
}

a.spells["divine_storm,if=variable.ds_castable&buff.divine_purpose.react"] = {
	ID = 53385--[[Divine Storm]],
	Melee = true,
	NoRangeCheck = true,
	CheckFirst = function(z)
		return variable.ds_castable and buff.divine_purpose.up
	end,
}

a.spells["divine_storm,if=variable.ds_castable&(!talent.crusade.enabled|cooldown.crusade.remains>gcd*2)"] = {
	ID = 53385--[[Divine Storm]],
	Melee = true,
	NoRangeCheck = true,
	CheckFirst = function(z)
		return variable.ds_castable and (not talent.crusade.enabled or cooldown.crusade.remains > x.MaxGCD * 2 or not x.UseLongCD)
	end,
}

a.spells["templars_verdict,if=buff.divine_purpose.react"] = {
	ID = 85256--[[Templar's Verdict]],
	CheckFirst = function(z)
		return buff.divine_purpose.up
	end,
}

a.spells["templars_verdict,if=(!talent.crusade.enabled|cooldown.crusade.remains>gcd*3)&(!talent.execution_sentence.enabled|buff.crusade.up&buff.crusade.stack<10|cooldown.execution_sentence.remains>gcd*2)"] = {
	ID = 85256--[[Templar's Verdict]],
	CheckFirst = function(z)
		return (not talent.crusade.enabled or cooldown.crusade.remains > x.MaxGCD * 3 or not x.UseLongCD) and (not talent.execution_sentence.enabled or buff.crusade.up and buff.crusade.stack < 10 or cooldown.execution_sentence.remains > x.MaxGCD * 2)
	end,
}

a.FlashFinishers = function()
	s.UpdateCooldown(31884, "Avenging Wrath")
	s.UpdateCooldown(231895, "Crusade")
	s.UpdateCooldown(267798, "Execution Sentence")
	s.UpdateBuff(278523, "Divine Right")
	--,"variable,name=ds_castable,value=spell_targets.divine_storm>=2|azerite.divine_right.enabled&target.health.pct<=20&buff.divine_right.down"
	variable.ds_castable = x.ActiveEnemies >= 2 or azerite.divine_right.enabled and target.health.pct <= 20 and buff.divine_right.down
	return a.Flash(
		"inquisition,if=buff.inquisition.down|buff.inquisition.remains<5&holy_power>=3|talent.execution_sentence.enabled&cooldown.execution_sentence.remains<10&buff.inquisition.remains<15|cooldown.avenging_wrath.remains<15&buff.inquisition.remains<20&holy_power>=3"
		,"execution_sentence,if=spell_targets.divine_storm<=2&(!talent.crusade.enabled|cooldown.crusade.remains>gcd*2)"
		,"divine_storm,if=variable.ds_castable&buff.divine_purpose.react"
		,"divine_storm,if=variable.ds_castable&(!talent.crusade.enabled|cooldown.crusade.remains>gcd*2)"
		,"templars_verdict,if=buff.divine_purpose.react"
		,"templars_verdict,if=(!talent.crusade.enabled|cooldown.crusade.remains>gcd*3)&(!talent.execution_sentence.enabled|buff.crusade.up&buff.crusade.stack<10|cooldown.execution_sentence.remains>gcd*2)"
	)
end

--[[
   ____                           _                 
  / ___| ___ _ __   ___ _ __ __ _| |_ ___  _ __ ___ 
 | |  _ / _ \ '_ \ / _ \ '__/ _` | __/ _ \| '__/ __|
 | |_| |  __/ | | |  __/ | | (_| | || (_) | |  \__ \
  \____|\___|_| |_|\___|_|  \__,_|\__\___/|_|  |___/
                                                    ]]

a.spells["wake_of_ashes,if=(!raid_event.adds.exists|raid_event.adds.in>15|spell_targets.wake_of_ashes>=2)&(holy_power<=0|holy_power=1&cooldown.blade_of_justice.remains>gcd)"] = {
	ID = 255937--[[Wake of Ashes]],
	NoRangeCheck = true,
	Melee = true,
	Check = function(z)
		return x.ActiveEnemies >= 2 and (x.HolyPower <= 0 or x.HolyPower == 1 and cooldown.blade_of_justice.remains > x.MaxGCD)
	end,
}

a.spells["blade_of_justice,if=holy_power<=2|(holy_power=3&(cooldown.hammer_of_wrath.remains>gcd*2|variable.HoW))"] = {
	ID = 184575--[[Blade of Justice]],
	CheckFirst = function(z)
		return x.HolyPower <= 2 or (x.HolyPower == 3 and (cooldown.hammer_of_wrath.remains > x.MaxGCD * 2 or variable.HoW))
	end,
}

a.spells["judgment,if=holy_power<=2|(holy_power<=4&(cooldown.blade_of_justice.remains>gcd*2|variable.HoW))"] = {
	ID = 20271--[[Judgement]],
	EnemyTargetNeeded = true,
	CheckFirst = function(z)
		return x.HolyPower <= 2 or (x.HolyPower <= 4 and (cooldown.blade_of_justice.remains > x.MaxGCD * 2 or variable.HoW))
	end,
}

a.spells["hammer_of_wrath,if=holy_power<=4"] = {
	ID = 24275--[[Hammer of Wrath]],
	EnemyTargetNeeded = true,
	CheckFirst = function(z)
		return x.HolyPower <= 4
	end,
}

a.spells["consecration,if=holy_power<=2|holy_power<=3&cooldown.blade_of_justice.remains>gcd*2|holy_power=4&cooldown.blade_of_justice.remains>gcd*2&cooldown.judgment.remains>gcd*2"] = {
	ID = 205228--[[Consecration]],
	NoRangeCheck = true,
	Melee = true,
	Check = function(z)
		return x.HolyPower <= 2 or x.HolyPower <= 3 and cooldown.blade_of_justice.remains > x.MaxGCD * 2 or x.HolyPower == 4 and cooldown.blade_of_justice.remains > x.MaxGCD * 2 and cooldown.judgment.remains > x.MaxGCD * 2
	end,
}

a.spells["crusader_strike,if=cooldown.crusader_strike.charges_fractional>=1.75&(holy_power<=2|holy_power<=3&cooldown.blade_of_justice.remains>gcd*2|holy_power=4&cooldown.blade_of_justice.remains>gcd*2&cooldown.judgment.remains>gcd*2&cooldown.consecration.remains>gcd*2)"] = {
	ID = 35395--[[Crusader Strike]],
	CheckFirst = function(z)
		return cooldown.crusader_strike.charges_fractional >= 1.75 and (x.HolyPower <= 2 or x.HolyPower <= 3 and cooldown.blade_of_justice.remains > x.MaxGCD * 2 or x.HolyPower == 4 and cooldown.blade_of_justice.remains > x.MaxGCD * 2 and cooldown.judgment.remains > x.MaxGCD * 2 and cooldown.consecration.remains > x.MaxGCD * 2)
	end,
}

a.spells["crusader_strike,if=holy_power<=4"] = {
	ID = 35395--[[Crusader Strike]],
	CheckFirst = function(z)
		return x.HolyPower <= 4
	end,
}

a.spells["arcane_torrent,if=(debuff.execution_sentence.up|(talent.hammer_of_wrath.enabled&(target.health.pct>=20|buff.avenging_wrath.down|buff.crusade.down))|!talent.execution_sentence.enabled|!talent.hammer_of_wrath.enabled)&holy_power<=4"] = {
	ID = 155145--[[Arcane Torrent]],
	NoRangeCheck = true,
	Melee = true,
	CheckFirst = function(z)
		return (debuff.execution_sentence.up or (talent.hammer_of_wrath.enabled and (target.health.pct >= 20 or buff.avenging_wrath.down or buff.crusade.down)) or not talent.execution_sentence.enabled or not talent.hammer_of_wrath.enabled) and x.HolyPower <= 4
	end,
}

--[[
   ___                             
  / _ \ _ __   ___ _ __   ___ _ __ 
 | | | | '_ \ / _ \ '_ \ / _ \ '__|
 | |_| | |_) |  __/ | | |  __/ |   
  \___/| .__/ \___|_| |_|\___|_|   
       |_|                         ]]
,"sequence,if=talent.wake_of_ashes.enabled&talent.crusade.enabled&talent.execution_sentence.enabled&!talent.hammer_of_wrath.enabled,name=wake_opener_ES_CS:shield_of_vengeance:blade_of_justice:judgment:crusade:templars_verdict:wake_of_ashes:templars_verdict:crusader_strike:execution_sentence"
,"sequence,if=talent.wake_of_ashes.enabled&talent.crusade.enabled&!talent.execution_sentence.enabled&!talent.hammer_of_wrath.enabled,name=wake_opener_CS:shield_of_vengeance:blade_of_justice:judgment:crusade:templars_verdict:wake_of_ashes:templars_verdict:crusader_strike:templars_verdict"
,"sequence,if=talent.wake_of_ashes.enabled&talent.crusade.enabled&talent.execution_sentence.enabled&talent.hammer_of_wrath.enabled,name=wake_opener_ES_HoW:shield_of_vengeance:blade_of_justice:judgment:crusade:templars_verdict:wake_of_ashes:templars_verdict:hammer_of_wrath:execution_sentence"
,"sequence,if=talent.wake_of_ashes.enabled&talent.crusade.enabled&!talent.execution_sentence.enabled&talent.hammer_of_wrath.enabled,name=wake_opener_HoW:shield_of_vengeance:blade_of_justice:judgment:crusade:templars_verdict:wake_of_ashes:templars_verdict:hammer_of_wrath:templars_verdict"
,"sequence,if=talent.wake_of_ashes.enabled&talent.inquisition.enabled,name=wake_opener_Inq:shield_of_vengeance:blade_of_justice:judgment:inquisition:avenging_wrath:wake_of_ashes"
